@@ -411,8 +411,8 @@ def open_sat_data(
 
     # add logger to preprocess function
     p_dedupe_time_coords = partial(dedupe_time_coords, logger=logger)
-    if str(zarr_path).split(".")[-1] == "nc":
-        dataset = xr.load_dataset(str(zarr_path), engine="h5netcdf")
+    if str(zarr_path).split(".")[-1] == "zip":
+        dataset = xr.load_dataset("zip:///" + str(zarr_path))
 
     else:
         # Open datasets.
